@@ -1,7 +1,7 @@
 package Complete::Number;
 
-our $DATE = '2015-09-03'; # DATE
-our $VERSION = '0.02'; # VERSION
+our $DATE = '2015-09-09'; # DATE
+our $VERSION = '0.03'; # VERSION
 
 use 5.010001;
 use strict;
@@ -9,7 +9,7 @@ use warnings;
 #use experimental 'smartmatch';
 #use Log::Any::IfLOG '$log';
 
-use Complete;
+use Complete::Setting;
 
 require Exporter;
 our @ISA       = qw(Exporter);
@@ -49,7 +49,7 @@ sub complete_int {
 
     my %args = @_;
     my $word = $args{word} // "";
-    my $ci   = $args{ci} // $Complete::OPT_CI;
+    my $ci   = $args{ci} // $Complete::Setting::OPT_CI;
 
     my @words;
 
@@ -111,7 +111,7 @@ sub complete_float {
 
     my %args = @_;
     my $word = $args{word} // "";
-    my $ci   = $args{ci} // $Complete::OPT_CI;
+    my $ci   = $args{ci} // $Complete::Setting::OPT_CI;
 
     my @words;
 
@@ -158,7 +158,7 @@ Complete::Number - Complete numbers
 
 =head1 VERSION
 
-This document describes version 0.02 of Complete::Number (from Perl distribution Complete-Number), released on 2015-09-03.
+This document describes version 0.03 of Complete::Number (from Perl distribution Complete-Number), released on 2015-09-09.
 
 =head1 SYNOPSIS
 
